==> rirods_0.1.1.tar.gz: rirods/tests/testthat/small-data-objects/stream-6ca07e.R <==
structure(list(method = "GET", url = "/stream?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fdfr.rds&offset=0&count=2000", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Thu, 29 Jun 2023 06:40:54 GMT", `Content-Length` = "400", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x58, 0x0a, 0x00, 0x00, 0x00, 0x03, 0x00, 
    0x04, 0x03, 0x00, 0x00, 0x03, 0x05, 0x00, 0x00, 0x00, 0x00, 
    0x05, 0x55, 0x54, 0x46, 0x2d, 0x38, 0x00, 0x00, 0x03, 0x13, 
    0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 
    0x00, 0x03, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 
    0x61, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 0x62, 
    0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 0x63, 0x00, 
    0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x0e, 0x63, 
    0x6f, 0x6d, 0x70, 0x61, 0x63, 0x74, 0x5f, 0x69, 0x6e, 0x74, 
    0x73, 0x65, 0x71, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x04, 0x62, 
    0x61, 0x73, 0x65, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x0d, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x0d, 0x00, 
    0x00, 0x00, 0xfe, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 
    0x03, 0x40, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 
    0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xf0, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 
    0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x01, 
    0xff, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0xff, 0x00, 
    0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0xfe, 0x00, 
    0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x03, 0x40, 0x08, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x18, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x3f, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 0x00, 0x04, 0x02, 0x00, 
    0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 
    0x05, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x00, 0x00, 0x00, 0x10, 
    0x00, 0x00, 0x00, 0x03, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 
    0x00, 0x01, 0x61, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 
    0x01, 0x62, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 
    0x63, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00, 0x00, 0x01, 0x00, 
    0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x05, 0x63, 0x6c, 0x61, 
    0x73, 0x73, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x01, 
    0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x0a, 0x64, 0x61, 
    0x74, 0x61, 0x2e, 0x66, 0x72, 0x61, 0x6d, 0x65, 0x00, 0x00, 
    0x04, 0x02, 0x00, 0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x09, 
    0x00, 0x00, 0x00, 0x09, 0x72, 0x6f, 0x77, 0x2e, 0x6e, 0x61, 
    0x6d, 0x65, 0x73, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 
    0x02, 0x80, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xfd, 0x00, 
    0x00, 0x00, 0xfe))), class = "httr2_response")

==> rirods_0.1.2.tar.gz: rirods/tests/testthat/small-data-objects/stream-6ca07e.R <==
structure(list(method = "GET", url = "/stream?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fdfr.rds&offset=0&count=2000", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:32 GMT", `Content-Length` = "400", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x58, 0x0a, 0x00, 0x00, 0x00, 0x03, 0x00, 
    0x04, 0x03, 0x01, 0x00, 0x03, 0x05, 0x00, 0x00, 0x00, 0x00, 
    0x05, 0x55, 0x54, 0x46, 0x2d, 0x38, 0x00, 0x00, 0x03, 0x13, 
    0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 
    0x00, 0x03, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 
    0x61, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 0x62, 
    0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 0x63, 0x00, 
    0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x0e, 0x63, 
    0x6f, 0x6d, 0x70, 0x61, 0x63, 0x74, 0x5f, 0x69, 0x6e, 0x74, 
    0x73, 0x65, 0x71, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x04, 0x62, 
    0x61, 0x73, 0x65, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 
    0x0d, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x0d, 0x00, 
    0x00, 0x00, 0xfe, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 
    0x03, 0x40, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 
    0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xf0, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 
    0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x01, 
    0xff, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0xff, 0x00, 
    0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 
    0x01, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 0xfe, 0x00, 
    0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x03, 0x40, 0x08, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x18, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x3f, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0xfe, 0x00, 0x00, 0x04, 0x02, 0x00, 
    0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 
    0x05, 0x6e, 0x61, 0x6d, 0x65, 0x73, 0x00, 0x00, 0x00, 0x10, 
    0x00, 0x00, 0x00, 0x03, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 
    0x00, 0x01, 0x61, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 
    0x01, 0x62, 0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x01, 
    0x63, 0x00, 0x00, 0x04, 0x02, 0x00, 0x00, 0x00, 0x01, 0x00, 
    0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x05, 0x63, 0x6c, 0x61, 
    0x73, 0x73, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x01, 
    0x00, 0x04, 0x00, 0x09, 0x00, 0x00, 0x00, 0x0a, 0x64, 0x61, 
    0x74, 0x61, 0x2e, 0x66, 0x72, 0x61, 0x6d, 0x65, 0x00, 0x00, 
    0x04, 0x02, 0x00, 0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x09, 
    0x00, 0x00, 0x00, 0x09, 0x72, 0x6f, 0x77, 0x2e, 0x6e, 0x61, 
    0x6d, 0x65, 0x73, 0x00, 0x00, 0x00, 0x0d, 0x00, 0x00, 0x00, 
    0x02, 0x80, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xfd, 0x00, 
    0x00, 0x00, 0xfe))), class = "httr2_response")
